@@ -18,6 +18,10 @@ class TitleValidator(Validator):
             'page.title.multiple': {
                 'title': 'Too many titles.',
                 'description': lambda value: "Page '%s' has %d title tags." % (value['page_url'], value['title_count'])
+            },
+            'page.title.size': {
+                'title': 'Maximum size of a page title',
+                'description': lambda value: 'Title is too long on "%s". The max size is %d characters.' % (value['page_url'], value['max_size'])
             }
         }
 
@@ -42,4 +46,12 @@ class TitleValidator(Validator):
                 },
                 points=50
             )
-            return
+        elif len(title[0]) > self.reviewer.config.MAX_TITLE_SIZE:
+            self.add_violation(
+                key='page.title.size',
+                value={
+                    'page_url': self.reviewer.page_url,
+                    'max_size': self.reviewer.config.MAX_TITLE_SIZE
+                },
+                points=10
+            )
